==> kubernetes-model-networking-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/ServiceBackendPortBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ServiceBackendPortBuilder extends io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortFluentImpl<io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPort,io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortBuilder>{
  public ServiceBackendPortBuilder() {
    this(false);
  }
  public ServiceBackendPortBuilder(java.lang.Boolean validationEnabled) {
    this(new ServiceBackendPort(), validationEnabled);
  }
  public ServiceBackendPortBuilder(io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceBackendPortBuilder(io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ServiceBackendPort(), validationEnabled);
  }
  public ServiceBackendPortBuilder(io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPort instance) {
    this(fluent, instance, false);
  }
  public ServiceBackendPortBuilder(io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPort instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withNumber(instance.getNumber()); 
    this.validationEnabled = validationEnabled; 
  }
  public ServiceBackendPortBuilder(io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPort instance) {
    this(instance,false);
  }
  public ServiceBackendPortBuilder(io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPort instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withNumber(instance.getNumber()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPort build() {
    ServiceBackendPort buildable = new ServiceBackendPort(fluent.getName(),fluent.getNumber());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ServiceBackendPortBuilder that = (ServiceBackendPortBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-networking-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/ServiceBackendPortBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ServiceBackendPortBuilder extends io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortFluentImpl<io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPort,io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortBuilder>{
  public ServiceBackendPortBuilder() {
    this(false);
  }
  public ServiceBackendPortBuilder(java.lang.Boolean validationEnabled) {
    this(new ServiceBackendPort(), validationEnabled);
  }
  public ServiceBackendPortBuilder(io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceBackendPortBuilder(io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ServiceBackendPort(), validationEnabled);
  }
  public ServiceBackendPortBuilder(io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPort instance) {
    this(fluent, instance, false);
  }
  public ServiceBackendPortBuilder(io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPort instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withNumber(instance.getNumber()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ServiceBackendPortBuilder(io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPort instance) {
    this(instance,false);
  }
  public ServiceBackendPortBuilder(io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPort instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withNumber(instance.getNumber()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPort build() {
    ServiceBackendPort buildable = new ServiceBackendPort(fluent.getName(),fluent.getNumber());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ServiceBackendPortBuilder that = (ServiceBackendPortBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
